mailmail: Send a mail message where 'mail' binary is available

Description Usage Arguments Value Examples

View source: R/mail.R

Description

Send a mail message where mail binary is available

Usage

1
2
3
4
5
6
7
mailmail(
  to = "btupper@bigelow.org",
  subject = "mail from charlier",
  message = "It's so wonderful to get mail, ain't it?",
  attachment = NULL,
  verbose = FALSE
)

Arguments

to

character, vector of one or more email addresses

subject

character subject line

message

character, vector of one or more lines of text

attachment

NULL or charcater, file path to optional attachment

verbose

logical, if TRUE then echo the command

Value

integer success code (0) or some non-zero if an error

Examples

1
2
3
4
5
6
7
8
## Not run: 
cat(LETTERS, sep = "\n", file = "letters.txt")
sendmail(to = "foo@bar.com",
         subject = "Facts",
         message = c("Fact: dogs start out as puppies.", "Not sure about cats."),
         attachment = "letters.txt")

## End(Not run)

BigelowLab/postal documentation built on Dec. 17, 2021, 10:51 a.m.