muttmail: Send a simple mail via mutt - see <URL: http://www.mutt.org/>

Description Usage Arguments Value See Also

View source: R/mail.R

Description

Send a simple mail via mutt - see http://www.mutt.org/

Usage

1
2
3
4
5
6
7
muttmail(
  to = "name@somewhere.org",
  subject = "mutt mail",
  message = paste("at", Sys.time(), "you have mutt mail"),
  attachment = NA,
  verbose = FALSE
)

Arguments

to

a character vector of one or more valid email addresses

subject

a character for the subject line (required)

message

- a character vector of one or more lines for the message body (NA to skip)

attachment

the fully qualified filename to attach (if any, NA to skip)

verbose

logical, if TRUE then echo the command

Value

0 for success and non-zero otherwise

See Also

Other mail: has_mail(), has_mutt(), has_nail(), nailmail(), sendmail()


BigelowLab/postal documentation built on Dec. 17, 2021, 10:51 a.m.