nailmail: Send a simple mail via nail - see <URL:...

Description Usage Arguments Value See Also

View source: R/mail.R

Description

Send a simple mail via nail - see http://linux.die.net/man/1/nail

Usage

1
2
3
4
5
6
7
nailmail(
  to = "name@somewhere.org",
  subject = "nail mail",
  message = paste("at", Sys.time(), "you have nail mail"),
  attachment = NA,
  verbose = FALSE
)

Arguments

to

a character vector of one or more valid email addresses

subject

a character for the subject line (required)

message

- a character vector of one or more lines for the message body (NA to skip)

attachment

the fully qualified filename to attach (if any, NA to skip)

verbose

logical, if TRUE then echo the command

Value

0 for success and non-zero otherwise

See Also

Other mail: has_mail(), has_mutt(), has_nail(), muttmail(), sendmail()


BigelowLab/postal documentation built on Dec. 17, 2021, 10:51 a.m.