sendmail: Send an email from R using the underlying mail services.

Description Usage Arguments Value See Also

View source: R/mail.R

Description

A simple wrapper around the platforms email engine. Currently mutt, nail and mail are supported, but the host must have these installed.

Usage

1
sendmail(..., app = c("mail", "mutt", "nail")[1])

Arguments

...

arguments for the mailer of choice.

app

the name of the mail engine to use, currently 'mail' (default), nail' and 'mutt' are supported

Value

value returned by the system-level mail program, non-zero for failure.

See Also

Other mail: has_mail(), has_mutt(), has_nail(), muttmail(), nailmail()


BigelowLab/postal documentation built on Dec. 17, 2021, 10:51 a.m.