Description Usage Arguments Value Examples
Send a mail message where mail binary is available
1 2 3 4 5 6 7 |
to |
character, vector of one or more email addresses |
subject |
character subject line |
message |
character, vector of one or more lines of text |
attachment |
NULL or charcater, file path to optional attachment |
verbose |
logical, if TRUE then echo the command |
integer success code (0) or some non-zero if an error
1 2 3 4 5 6 7 8 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.