Description Usage Arguments Value See Also
Send a simple mail via mutt - see http://www.mutt.org/
1 2 3 4 5 6 7 |
to |
a character vector of one or more valid email addresses |
subject |
a character for the subject line (required) |
message |
- a character vector of one or more lines for the message body (NA to skip) |
attachment |
the fully qualified filename to attach (if any, NA to skip) |
verbose |
logical, if TRUE then echo the command |
0 for success and non-zero otherwise
Other mail:
has_mail(),
has_mutt(),
has_nail(),
nailmail(),
sendmail()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.