Description Usage Arguments Value See Also
A simple wrapper around the platforms email engine. Currently mutt,
nail and mail are supported, but the host must have these installed.
1 |
... |
arguments for the mailer of choice. |
app |
the name of the mail engine to use, currently 'mail' (default), nail' and 'mutt' are supported |
value returned by the system-level mail program, non-zero for failure.
Other mail:
has_mail(),
has_mutt(),
has_nail(),
muttmail(),
nailmail()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.